@@ -18,12 +18,15 @@
 #ifndef LOCATIONLISTMODEL_H
 #define LOCATIONLISTMODEL_H
 
+#include <Plasma/DataEngineConsumer>
+
 #include <QAbstractListModel>
 #include <QVector>
 #include <QMap>
 
+namespace Plasma {
 class WeatherValidator;
-
+}
 
 class LocationItem
 {
@@ -44,7 +47,7 @@ Q_DECLARE_METATYPE(LocationItem)
 Q_DECLARE_TYPEINFO(LocationItem, Q_MOVABLE_TYPE);
 
 
-class LocationListModel : public QAbstractListModel
+class LocationListModel : public QAbstractListModel, public Plasma::DataEngineConsumer
 {
     Q_OBJECT
     Q_PROPERTY(bool validatingInput READ isValidatingInput NOTIFY validatingInputChanged)
@@ -62,7 +65,7 @@ public:
 public:
     Q_INVOKABLE QString nameForListIndex(int listIndex) const;
     Q_INVOKABLE QString valueForListIndex(int listIndex) const;
-    Q_INVOKABLE void searchLocations(const QString &searchString);
+    Q_INVOKABLE void searchLocations(const QString &searchString, const QStringList& services);
 
 Q_SIGNALS:
     void validatingInputChanged(bool validatingInput);
@@ -79,7 +82,7 @@ private:
     bool m_validatingInput;
     QString m_searchString;
     int m_checkedInCount;
-    QVector<WeatherValidator*> m_validators;
+    QVector<Plasma::WeatherValidator*> m_validators;
 };
 
 #endif // LOCATIONLISTMODEL_H
